# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/vpc/v1/security_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.vpc.v1 import security_group_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/vpc/v1/security_group_service.proto',
  package='yandex.cloud.vpc.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpc',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0yandex/cloud/vpc/v1/security_group_service.proto\x12\x13yandex.cloud.vpc.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a(yandex/cloud/vpc/v1/security_group.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\":\n\x17GetSecurityGroupRequest\x12\x1f\n\x11security_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"k\n\x19ListSecurityGroupsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"r\n\x1aListSecurityGroupsResponse\x12;\n\x0fsecurity_groups\x18\x01 \x03(\x0b\x32\".yandex.cloud.vpc.v1.SecurityGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xae\x02\n\x1a\x43reateSecurityGroupRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12K\n\x06labels\x18\x04 \x03(\x0b\x32;.yandex.cloud.vpc.v1.CreateSecurityGroupRequest.LabelsEntry\x12\x18\n\nnetwork_id\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\x12>\n\nrule_specs\x18\x06 \x03(\x0b\x32*.yandex.cloud.vpc.v1.SecurityGroupRuleSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdf\x03\n\x15SecurityGroupRuleSpec\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x46\n\x06labels\x18\x02 \x03(\x0b\x32\x36.yandex.cloud.vpc.v1.SecurityGroupRuleSpec.LabelsEntry\x12I\n\tdirection\x18\x03 \x01(\x0e\x32\x30.yandex.cloud.vpc.v1.SecurityGroupRule.DirectionB\x04\xe8\xc7\x31\x01\x12-\n\x05ports\x18\x04 \x01(\x0b\x32\x1e.yandex.cloud.vpc.v1.PortRange\x12\x17\n\rprotocol_name\x18\x05 \x01(\tH\x00\x12\x19\n\x0fprotocol_number\x18\x06 \x01(\x03H\x00\x12\x36\n\x0b\x63idr_blocks\x18\x07 \x01(\x0b\x32\x1f.yandex.cloud.vpc.v1.CidrBlocksH\x01\x12\x1b\n\x11security_group_id\x18\x08 \x01(\tH\x01\x12\x1b\n\x11predefined_target\x18\t \x01(\tH\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\n\n\x08protocolB\x0e\n\x06target\x12\x04\xc0\xc1\x31\x01\"8\n\x1b\x43reateSecurityGroupMetadata\x12\x19\n\x11security_group_id\x18\x01 \x01(\t\"\xcd\x02\n\x1aUpdateSecurityGroupRequest\x12\x1f\n\x11security_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12K\n\x06labels\x18\x05 \x03(\x0b\x32;.yandex.cloud.vpc.v1.UpdateSecurityGroupRequest.LabelsEntry\x12>\n\nrule_specs\x18\x06 \x03(\x0b\x32*.yandex.cloud.vpc.v1.SecurityGroupRuleSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"8\n\x1bUpdateSecurityGroupMetadata\x12\x19\n\x11security_group_id\x18\x01 \x01(\t\"\xa6\x01\n\x1fUpdateSecurityGroupRulesRequest\x12\x1f\n\x11security_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x11\x64\x65letion_rule_ids\x18\x02 \x03(\t\x12G\n\x13\x61\x64\x64ition_rule_specs\x18\x03 \x03(\x0b\x32*.yandex.cloud.vpc.v1.SecurityGroupRuleSpec\"\x9e\x02\n\x1eUpdateSecurityGroupRuleRequest\x12\x1f\n\x11security_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x15\n\x07rule_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12O\n\x06labels\x18\x05 \x03(\x0b\x32?.yandex.cloud.vpc.v1.UpdateSecurityGroupRuleRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"M\n\x1fUpdateSecurityGroupRuleMetadata\x12\x19\n\x11security_group_id\x18\x01 \x01(\t\x12\x0f\n\x07rule_id\x18\x02 \x01(\t\"=\n\x1a\x44\x65leteSecurityGroupRequest\x12\x1f\n\x11security_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"8\n\x1b\x44\x65leteSecurityGroupMetadata\x12\x19\n\x11security_group_id\x18\x01 \x01(\t\"l\n\"ListSecurityGroupOperationsRequest\x12\x1f\n\x11security_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"u\n#ListSecurityGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"`\n\x18MoveSecurityGroupRequest\x12\x1f\n\x11security_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12#\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"6\n\x19MoveSecurityGroupMetadata\x12\x19\n\x11security_group_id\x18\x01 \x01(\t2\xe0\t\n\x14SecurityGroupService\x12W\n\x03Get\x12,.yandex.cloud.vpc.v1.GetSecurityGroupRequest\x1a\".yandex.cloud.vpc.v1.SecurityGroup\x12g\n\x04List\x12..yandex.cloud.vpc.v1.ListSecurityGroupsRequest\x1a/.yandex.cloud.vpc.v1.ListSecurityGroupsResponse\x12\x8e\x01\n\x06\x43reate\x12/.yandex.cloud.vpc.v1.CreateSecurityGroupRequest\x1a!.yandex.cloud.operation.Operation\"0\xb2\xd2*,\n\x1b\x43reateSecurityGroupMetadata\x12\rSecurityGroup\x12\x8e\x01\n\x06Update\x12/.yandex.cloud.vpc.v1.UpdateSecurityGroupRequest\x1a!.yandex.cloud.operation.Operation\"0\xb2\xd2*,\n\x1bUpdateSecurityGroupMetadata\x12\rSecurityGroup\x12\x98\x01\n\x0bUpdateRules\x12\x34.yandex.cloud.vpc.v1.UpdateSecurityGroupRulesRequest\x1a!.yandex.cloud.operation.Operation\"0\xb2\xd2*,\n\x1bUpdateSecurityGroupMetadata\x12\rSecurityGroup\x12\x9e\x01\n\nUpdateRule\x12\x33.yandex.cloud.vpc.v1.UpdateSecurityGroupRuleRequest\x1a!.yandex.cloud.operation.Operation\"8\xb2\xd2*4\n\x1fUpdateSecurityGroupRuleMetadata\x12\x11SecurityGroupRule\x12\x96\x01\n\x06\x44\x65lete\x12/.yandex.cloud.vpc.v1.DeleteSecurityGroupRequest\x1a!.yandex.cloud.operation.Operation\"8\xb2\xd2*4\n\x1b\x44\x65leteSecurityGroupMetadata\x12\x15google.protobuf.Empty\x12\x88\x01\n\x04Move\x12-.yandex.cloud.vpc.v1.MoveSecurityGroupRequest\x1a!.yandex.cloud.operation.Operation\".\xb2\xd2**\n\x19MoveSecurityGroupMetadata\x12\rSecurityGroup\x12\x83\x01\n\x0eListOperations\x12\x37.yandex.cloud.vpc.v1.ListSecurityGroupOperationsRequest\x1a\x38.yandex.cloud.vpc.v1.ListSecurityGroupOperationsResponseBV\n\x17yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpcb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETSECURITYGROUPREQUEST = _descriptor.Descriptor(
  name='GetSecurityGroupRequest',
  full_name='yandex.cloud.vpc.v1.GetSecurityGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_group_id', full_name='yandex.cloud.vpc.v1.GetSecurityGroupRequest.security_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=342,
)


_LISTSECURITYGROUPSREQUEST = _descriptor.Descriptor(
  name='ListSecurityGroupsRequest',
  full_name='yandex.cloud.vpc.v1.ListSecurityGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.vpc.v1.ListSecurityGroupsRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.vpc.v1.ListSecurityGroupsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.vpc.v1.ListSecurityGroupsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.vpc.v1.ListSecurityGroupsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=344,
  serialized_end=451,
)


_LISTSECURITYGROUPSRESPONSE = _descriptor.Descriptor(
  name='ListSecurityGroupsResponse',
  full_name='yandex.cloud.vpc.v1.ListSecurityGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_groups', full_name='yandex.cloud.vpc.v1.ListSecurityGroupsResponse.security_groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.vpc.v1.ListSecurityGroupsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=567,
)


_CREATESECURITYGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.vpc.v1.CreateSecurityGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.vpc.v1.CreateSecurityGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.vpc.v1.CreateSecurityGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=827,
  serialized_end=872,
)

_CREATESECURITYGROUPREQUEST = _descriptor.Descriptor(
  name='CreateSecurityGroupRequest',
  full_name='yandex.cloud.vpc.v1.CreateSecurityGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.vpc.v1.CreateSecurityGroupRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.vpc.v1.CreateSecurityGroupRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.vpc.v1.CreateSecurityGroupRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.vpc.v1.CreateSecurityGroupRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.vpc.v1.CreateSecurityGroupRequest.network_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rule_specs', full_name='yandex.cloud.vpc.v1.CreateSecurityGroupRequest.rule_specs', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATESECURITYGROUPREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=872,
)


_SECURITYGROUPRULESPEC_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.vpc.v1.SecurityGroupRuleSpec.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.vpc.v1.SecurityGroupRuleSpec.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.vpc.v1.SecurityGroupRuleSpec.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=827,
  serialized_end=872,
)

_SECURITYGROUPRULESPEC = _descriptor.Descriptor(
  name='SecurityGroupRuleSpec',
  full_name='yandex.cloud.vpc.v1.SecurityGroupRuleSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.vpc.v1.SecurityGroupRuleSpec.description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.vpc.v1.SecurityGroupRuleSpec.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='yandex.cloud.vpc.v1.SecurityGroupRuleSpec.direction', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ports', full_name='yandex.cloud.vpc.v1.SecurityGroupRuleSpec.ports', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_name', full_name='yandex.cloud.vpc.v1.SecurityGroupRuleSpec.protocol_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_number', full_name='yandex.cloud.vpc.v1.SecurityGroupRuleSpec.protocol_number', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cidr_blocks', full_name='yandex.cloud.vpc.v1.SecurityGroupRuleSpec.cidr_blocks', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_group_id', full_name='yandex.cloud.vpc.v1.SecurityGroupRuleSpec.security_group_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='predefined_target', full_name='yandex.cloud.vpc.v1.SecurityGroupRuleSpec.predefined_target', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SECURITYGROUPRULESPEC_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='protocol', full_name='yandex.cloud.vpc.v1.SecurityGroupRuleSpec.protocol',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='target', full_name='yandex.cloud.vpc.v1.SecurityGroupRuleSpec.target',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=875,
  serialized_end=1354,
)


_CREATESECURITYGROUPMETADATA = _descriptor.Descriptor(
  name='CreateSecurityGroupMetadata',
  full_name='yandex.cloud.vpc.v1.CreateSecurityGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_group_id', full_name='yandex.cloud.vpc.v1.CreateSecurityGroupMetadata.security_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1356,
  serialized_end=1412,
)


_UPDATESECURITYGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=827,
  serialized_end=872,
)

_UPDATESECURITYGROUPREQUEST = _descriptor.Descriptor(
  name='UpdateSecurityGroupRequest',
  full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_group_id', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRequest.security_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rule_specs', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRequest.rule_specs', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATESECURITYGROUPREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1415,
  serialized_end=1748,
)


_UPDATESECURITYGROUPMETADATA = _descriptor.Descriptor(
  name='UpdateSecurityGroupMetadata',
  full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_group_id', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupMetadata.security_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1750,
  serialized_end=1806,
)


_UPDATESECURITYGROUPRULESREQUEST = _descriptor.Descriptor(
  name='UpdateSecurityGroupRulesRequest',
  full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRulesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_group_id', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRulesRequest.security_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_rule_ids', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRulesRequest.deletion_rule_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='addition_rule_specs', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRulesRequest.addition_rule_specs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1809,
  serialized_end=1975,
)


_UPDATESECURITYGROUPRULEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRuleRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRuleRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRuleRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=827,
  serialized_end=872,
)

_UPDATESECURITYGROUPRULEREQUEST = _descriptor.Descriptor(
  name='UpdateSecurityGroupRuleRequest',
  full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRuleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_group_id', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRuleRequest.security_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rule_id', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRuleRequest.rule_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRuleRequest.update_mask', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRuleRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRuleRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATESECURITYGROUPRULEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1978,
  serialized_end=2264,
)


_UPDATESECURITYGROUPRULEMETADATA = _descriptor.Descriptor(
  name='UpdateSecurityGroupRuleMetadata',
  full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRuleMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_group_id', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRuleMetadata.security_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rule_id', full_name='yandex.cloud.vpc.v1.UpdateSecurityGroupRuleMetadata.rule_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2266,
  serialized_end=2343,
)


_DELETESECURITYGROUPREQUEST = _descriptor.Descriptor(
  name='DeleteSecurityGroupRequest',
  full_name='yandex.cloud.vpc.v1.DeleteSecurityGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_group_id', full_name='yandex.cloud.vpc.v1.DeleteSecurityGroupRequest.security_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2345,
  serialized_end=2406,
)


_DELETESECURITYGROUPMETADATA = _descriptor.Descriptor(
  name='DeleteSecurityGroupMetadata',
  full_name='yandex.cloud.vpc.v1.DeleteSecurityGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_group_id', full_name='yandex.cloud.vpc.v1.DeleteSecurityGroupMetadata.security_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2408,
  serialized_end=2464,
)


_LISTSECURITYGROUPOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListSecurityGroupOperationsRequest',
  full_name='yandex.cloud.vpc.v1.ListSecurityGroupOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_group_id', full_name='yandex.cloud.vpc.v1.ListSecurityGroupOperationsRequest.security_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.vpc.v1.ListSecurityGroupOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.vpc.v1.ListSecurityGroupOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2466,
  serialized_end=2574,
)


_LISTSECURITYGROUPOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListSecurityGroupOperationsResponse',
  full_name='yandex.cloud.vpc.v1.ListSecurityGroupOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.vpc.v1.ListSecurityGroupOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.vpc.v1.ListSecurityGroupOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2576,
  serialized_end=2693,
)


_MOVESECURITYGROUPREQUEST = _descriptor.Descriptor(
  name='MoveSecurityGroupRequest',
  full_name='yandex.cloud.vpc.v1.MoveSecurityGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_group_id', full_name='yandex.cloud.vpc.v1.MoveSecurityGroupRequest.security_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_folder_id', full_name='yandex.cloud.vpc.v1.MoveSecurityGroupRequest.destination_folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2695,
  serialized_end=2791,
)


_MOVESECURITYGROUPMETADATA = _descriptor.Descriptor(
  name='MoveSecurityGroupMetadata',
  full_name='yandex.cloud.vpc.v1.MoveSecurityGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='security_group_id', full_name='yandex.cloud.vpc.v1.MoveSecurityGroupMetadata.security_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2793,
  serialized_end=2847,
)

_LISTSECURITYGROUPSRESPONSE.fields_by_name['security_groups'].message_type = yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__pb2._SECURITYGROUP
_CREATESECURITYGROUPREQUEST_LABELSENTRY.containing_type = _CREATESECURITYGROUPREQUEST
_CREATESECURITYGROUPREQUEST.fields_by_name['labels'].message_type = _CREATESECURITYGROUPREQUEST_LABELSENTRY
_CREATESECURITYGROUPREQUEST.fields_by_name['rule_specs'].message_type = _SECURITYGROUPRULESPEC
_SECURITYGROUPRULESPEC_LABELSENTRY.containing_type = _SECURITYGROUPRULESPEC
_SECURITYGROUPRULESPEC.fields_by_name['labels'].message_type = _SECURITYGROUPRULESPEC_LABELSENTRY
_SECURITYGROUPRULESPEC.fields_by_name['direction'].enum_type = yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__pb2._SECURITYGROUPRULE_DIRECTION
_SECURITYGROUPRULESPEC.fields_by_name['ports'].message_type = yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__pb2._PORTRANGE
_SECURITYGROUPRULESPEC.fields_by_name['cidr_blocks'].message_type = yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__pb2._CIDRBLOCKS
_SECURITYGROUPRULESPEC.oneofs_by_name['protocol'].fields.append(
  _SECURITYGROUPRULESPEC.fields_by_name['protocol_name'])
_SECURITYGROUPRULESPEC.fields_by_name['protocol_name'].containing_oneof = _SECURITYGROUPRULESPEC.oneofs_by_name['protocol']
_SECURITYGROUPRULESPEC.oneofs_by_name['protocol'].fields.append(
  _SECURITYGROUPRULESPEC.fields_by_name['protocol_number'])
_SECURITYGROUPRULESPEC.fields_by_name['protocol_number'].containing_oneof = _SECURITYGROUPRULESPEC.oneofs_by_name['protocol']
_SECURITYGROUPRULESPEC.oneofs_by_name['target'].fields.append(
  _SECURITYGROUPRULESPEC.fields_by_name['cidr_blocks'])
_SECURITYGROUPRULESPEC.fields_by_name['cidr_blocks'].containing_oneof = _SECURITYGROUPRULESPEC.oneofs_by_name['target']
_SECURITYGROUPRULESPEC.oneofs_by_name['target'].fields.append(
  _SECURITYGROUPRULESPEC.fields_by_name['security_group_id'])
_SECURITYGROUPRULESPEC.fields_by_name['security_group_id'].containing_oneof = _SECURITYGROUPRULESPEC.oneofs_by_name['target']
_SECURITYGROUPRULESPEC.oneofs_by_name['target'].fields.append(
  _SECURITYGROUPRULESPEC.fields_by_name['predefined_target'])
_SECURITYGROUPRULESPEC.fields_by_name['predefined_target'].containing_oneof = _SECURITYGROUPRULESPEC.oneofs_by_name['target']
_UPDATESECURITYGROUPREQUEST_LABELSENTRY.containing_type = _UPDATESECURITYGROUPREQUEST
_UPDATESECURITYGROUPREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATESECURITYGROUPREQUEST.fields_by_name['labels'].message_type = _UPDATESECURITYGROUPREQUEST_LABELSENTRY
_UPDATESECURITYGROUPREQUEST.fields_by_name['rule_specs'].message_type = _SECURITYGROUPRULESPEC
_UPDATESECURITYGROUPRULESREQUEST.fields_by_name['addition_rule_specs'].message_type = _SECURITYGROUPRULESPEC
_UPDATESECURITYGROUPRULEREQUEST_LABELSENTRY.containing_type = _UPDATESECURITYGROUPRULEREQUEST
_UPDATESECURITYGROUPRULEREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATESECURITYGROUPRULEREQUEST.fields_by_name['labels'].message_type = _UPDATESECURITYGROUPRULEREQUEST_LABELSENTRY
_LISTSECURITYGROUPOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetSecurityGroupRequest'] = _GETSECURITYGROUPREQUEST
DESCRIPTOR.message_types_by_name['ListSecurityGroupsRequest'] = _LISTSECURITYGROUPSREQUEST
DESCRIPTOR.message_types_by_name['ListSecurityGroupsResponse'] = _LISTSECURITYGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['CreateSecurityGroupRequest'] = _CREATESECURITYGROUPREQUEST
DESCRIPTOR.message_types_by_name['SecurityGroupRuleSpec'] = _SECURITYGROUPRULESPEC
DESCRIPTOR.message_types_by_name['CreateSecurityGroupMetadata'] = _CREATESECURITYGROUPMETADATA
DESCRIPTOR.message_types_by_name['UpdateSecurityGroupRequest'] = _UPDATESECURITYGROUPREQUEST
DESCRIPTOR.message_types_by_name['UpdateSecurityGroupMetadata'] = _UPDATESECURITYGROUPMETADATA
DESCRIPTOR.message_types_by_name['UpdateSecurityGroupRulesRequest'] = _UPDATESECURITYGROUPRULESREQUEST
DESCRIPTOR.message_types_by_name['UpdateSecurityGroupRuleRequest'] = _UPDATESECURITYGROUPRULEREQUEST
DESCRIPTOR.message_types_by_name['UpdateSecurityGroupRuleMetadata'] = _UPDATESECURITYGROUPRULEMETADATA
DESCRIPTOR.message_types_by_name['DeleteSecurityGroupRequest'] = _DELETESECURITYGROUPREQUEST
DESCRIPTOR.message_types_by_name['DeleteSecurityGroupMetadata'] = _DELETESECURITYGROUPMETADATA
DESCRIPTOR.message_types_by_name['ListSecurityGroupOperationsRequest'] = _LISTSECURITYGROUPOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListSecurityGroupOperationsResponse'] = _LISTSECURITYGROUPOPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['MoveSecurityGroupRequest'] = _MOVESECURITYGROUPREQUEST
DESCRIPTOR.message_types_by_name['MoveSecurityGroupMetadata'] = _MOVESECURITYGROUPMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetSecurityGroupRequest = _reflection.GeneratedProtocolMessageType('GetSecurityGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSECURITYGROUPREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.GetSecurityGroupRequest)
  })
_sym_db.RegisterMessage(GetSecurityGroupRequest)

ListSecurityGroupsRequest = _reflection.GeneratedProtocolMessageType('ListSecurityGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSECURITYGROUPSREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListSecurityGroupsRequest)
  })
_sym_db.RegisterMessage(ListSecurityGroupsRequest)

ListSecurityGroupsResponse = _reflection.GeneratedProtocolMessageType('ListSecurityGroupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSECURITYGROUPSRESPONSE,
  '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListSecurityGroupsResponse)
  })
_sym_db.RegisterMessage(ListSecurityGroupsResponse)

CreateSecurityGroupRequest = _reflection.GeneratedProtocolMessageType('CreateSecurityGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATESECURITYGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.CreateSecurityGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATESECURITYGROUPREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.CreateSecurityGroupRequest)
  })
_sym_db.RegisterMessage(CreateSecurityGroupRequest)
_sym_db.RegisterMessage(CreateSecurityGroupRequest.LabelsEntry)

SecurityGroupRuleSpec = _reflection.GeneratedProtocolMessageType('SecurityGroupRuleSpec', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SECURITYGROUPRULESPEC_LABELSENTRY,
    '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.SecurityGroupRuleSpec.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _SECURITYGROUPRULESPEC,
  '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.SecurityGroupRuleSpec)
  })
_sym_db.RegisterMessage(SecurityGroupRuleSpec)
_sym_db.RegisterMessage(SecurityGroupRuleSpec.LabelsEntry)

CreateSecurityGroupMetadata = _reflection.GeneratedProtocolMessageType('CreateSecurityGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATESECURITYGROUPMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.CreateSecurityGroupMetadata)
  })
_sym_db.RegisterMessage(CreateSecurityGroupMetadata)

UpdateSecurityGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateSecurityGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATESECURITYGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateSecurityGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATESECURITYGROUPREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateSecurityGroupRequest)
  })
_sym_db.RegisterMessage(UpdateSecurityGroupRequest)
_sym_db.RegisterMessage(UpdateSecurityGroupRequest.LabelsEntry)

UpdateSecurityGroupMetadata = _reflection.GeneratedProtocolMessageType('UpdateSecurityGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESECURITYGROUPMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateSecurityGroupMetadata)
  })
_sym_db.RegisterMessage(UpdateSecurityGroupMetadata)

UpdateSecurityGroupRulesRequest = _reflection.GeneratedProtocolMessageType('UpdateSecurityGroupRulesRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESECURITYGROUPRULESREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateSecurityGroupRulesRequest)
  })
_sym_db.RegisterMessage(UpdateSecurityGroupRulesRequest)

UpdateSecurityGroupRuleRequest = _reflection.GeneratedProtocolMessageType('UpdateSecurityGroupRuleRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATESECURITYGROUPRULEREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateSecurityGroupRuleRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATESECURITYGROUPRULEREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateSecurityGroupRuleRequest)
  })
_sym_db.RegisterMessage(UpdateSecurityGroupRuleRequest)
_sym_db.RegisterMessage(UpdateSecurityGroupRuleRequest.LabelsEntry)

UpdateSecurityGroupRuleMetadata = _reflection.GeneratedProtocolMessageType('UpdateSecurityGroupRuleMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESECURITYGROUPRULEMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateSecurityGroupRuleMetadata)
  })
_sym_db.RegisterMessage(UpdateSecurityGroupRuleMetadata)

DeleteSecurityGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteSecurityGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESECURITYGROUPREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.DeleteSecurityGroupRequest)
  })
_sym_db.RegisterMessage(DeleteSecurityGroupRequest)

DeleteSecurityGroupMetadata = _reflection.GeneratedProtocolMessageType('DeleteSecurityGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETESECURITYGROUPMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.DeleteSecurityGroupMetadata)
  })
_sym_db.RegisterMessage(DeleteSecurityGroupMetadata)

ListSecurityGroupOperationsRequest = _reflection.GeneratedProtocolMessageType('ListSecurityGroupOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSECURITYGROUPOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListSecurityGroupOperationsRequest)
  })
_sym_db.RegisterMessage(ListSecurityGroupOperationsRequest)

ListSecurityGroupOperationsResponse = _reflection.GeneratedProtocolMessageType('ListSecurityGroupOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSECURITYGROUPOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListSecurityGroupOperationsResponse)
  })
_sym_db.RegisterMessage(ListSecurityGroupOperationsResponse)

MoveSecurityGroupRequest = _reflection.GeneratedProtocolMessageType('MoveSecurityGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVESECURITYGROUPREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.MoveSecurityGroupRequest)
  })
_sym_db.RegisterMessage(MoveSecurityGroupRequest)

MoveSecurityGroupMetadata = _reflection.GeneratedProtocolMessageType('MoveSecurityGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _MOVESECURITYGROUPMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.security_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.MoveSecurityGroupMetadata)
  })
_sym_db.RegisterMessage(MoveSecurityGroupMetadata)


DESCRIPTOR._options = None
_GETSECURITYGROUPREQUEST.fields_by_name['security_group_id']._options = None
_LISTSECURITYGROUPSREQUEST.fields_by_name['folder_id']._options = None
_CREATESECURITYGROUPREQUEST_LABELSENTRY._options = None
_CREATESECURITYGROUPREQUEST.fields_by_name['folder_id']._options = None
_CREATESECURITYGROUPREQUEST.fields_by_name['network_id']._options = None
_SECURITYGROUPRULESPEC_LABELSENTRY._options = None
_SECURITYGROUPRULESPEC.oneofs_by_name['target']._options = None
_SECURITYGROUPRULESPEC.fields_by_name['direction']._options = None
_UPDATESECURITYGROUPREQUEST_LABELSENTRY._options = None
_UPDATESECURITYGROUPREQUEST.fields_by_name['security_group_id']._options = None
_UPDATESECURITYGROUPRULESREQUEST.fields_by_name['security_group_id']._options = None
_UPDATESECURITYGROUPRULEREQUEST_LABELSENTRY._options = None
_UPDATESECURITYGROUPRULEREQUEST.fields_by_name['security_group_id']._options = None
_UPDATESECURITYGROUPRULEREQUEST.fields_by_name['rule_id']._options = None
_DELETESECURITYGROUPREQUEST.fields_by_name['security_group_id']._options = None
_LISTSECURITYGROUPOPERATIONSREQUEST.fields_by_name['security_group_id']._options = None
_MOVESECURITYGROUPREQUEST.fields_by_name['security_group_id']._options = None
_MOVESECURITYGROUPREQUEST.fields_by_name['destination_folder_id']._options = None

_SECURITYGROUPSERVICE = _descriptor.ServiceDescriptor(
  name='SecurityGroupService',
  full_name='yandex.cloud.vpc.v1.SecurityGroupService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2850,
  serialized_end=4098,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.vpc.v1.SecurityGroupService.Get',
    index=0,
    containing_service=None,
    input_type=_GETSECURITYGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__pb2._SECURITYGROUP,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.vpc.v1.SecurityGroupService.List',
    index=1,
    containing_service=None,
    input_type=_LISTSECURITYGROUPSREQUEST,
    output_type=_LISTSECURITYGROUPSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.vpc.v1.SecurityGroupService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATESECURITYGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322*,\n\033CreateSecurityGroupMetadata\022\rSecurityGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.vpc.v1.SecurityGroupService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATESECURITYGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322*,\n\033UpdateSecurityGroupMetadata\022\rSecurityGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRules',
    full_name='yandex.cloud.vpc.v1.SecurityGroupService.UpdateRules',
    index=4,
    containing_service=None,
    input_type=_UPDATESECURITYGROUPRULESREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322*,\n\033UpdateSecurityGroupMetadata\022\rSecurityGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRule',
    full_name='yandex.cloud.vpc.v1.SecurityGroupService.UpdateRule',
    index=5,
    containing_service=None,
    input_type=_UPDATESECURITYGROUPRULEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322*4\n\037UpdateSecurityGroupRuleMetadata\022\021SecurityGroupRule',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.vpc.v1.SecurityGroupService.Delete',
    index=6,
    containing_service=None,
    input_type=_DELETESECURITYGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322*4\n\033DeleteSecurityGroupMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Move',
    full_name='yandex.cloud.vpc.v1.SecurityGroupService.Move',
    index=7,
    containing_service=None,
    input_type=_MOVESECURITYGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322**\n\031MoveSecurityGroupMetadata\022\rSecurityGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.vpc.v1.SecurityGroupService.ListOperations',
    index=8,
    containing_service=None,
    input_type=_LISTSECURITYGROUPOPERATIONSREQUEST,
    output_type=_LISTSECURITYGROUPOPERATIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SECURITYGROUPSERVICE)

DESCRIPTOR.services_by_name['SecurityGroupService'] = _SECURITYGROUPSERVICE

# @@protoc_insertion_point(module_scope)
