# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.apploadbalancer.v1 import load_balancer_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2
from yandex.cloud.apploadbalancer.v1 import load_balancer_service_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class LoadBalancerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Get',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.GetLoadBalancerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2.LoadBalancer.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/List',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancersRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancersResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Create',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.CreateLoadBalancerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Update',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.UpdateLoadBalancerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Delete',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.DeleteLoadBalancerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Start = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Start',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.StartLoadBalancerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Stop = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Stop',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.StopLoadBalancerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.AddListener = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/AddListener',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.AddListenerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.RemoveListener = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/RemoveListener',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.RemoveListenerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateListener = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/UpdateListener',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.UpdateListenerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.AddSniMatch = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/AddSniMatch',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.AddSniMatchRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateSniMatch = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/UpdateSniMatch',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.UpdateSniMatchRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.RemoveSniMatch = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/RemoveSniMatch',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.RemoveSniMatchRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.GetTargetStates = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/GetTargetStates',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.GetTargetStatesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.GetTargetStatesResponse.FromString,
                )
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancerOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancerOperationsResponse.FromString,
                )


class LoadBalancerServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Start(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stop(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddListener(self, request, context):
        """AddListener/UpdateListener technically do the same, but have different semantics.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveListener(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateListener(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddSniMatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSniMatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveSniMatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTargetStates(self, request, context):
        """Returns zonal state of each target within target group
        for a given backend group and load balancer.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified load balancer.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LoadBalancerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.GetLoadBalancerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2.LoadBalancer.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancersRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancersResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.CreateLoadBalancerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.UpdateLoadBalancerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.DeleteLoadBalancerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Start': grpc.unary_unary_rpc_method_handler(
                    servicer.Start,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.StartLoadBalancerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Stop': grpc.unary_unary_rpc_method_handler(
                    servicer.Stop,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.StopLoadBalancerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'AddListener': grpc.unary_unary_rpc_method_handler(
                    servicer.AddListener,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.AddListenerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'RemoveListener': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveListener,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.RemoveListenerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateListener': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateListener,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.UpdateListenerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'AddSniMatch': grpc.unary_unary_rpc_method_handler(
                    servicer.AddSniMatch,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.AddSniMatchRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateSniMatch': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSniMatch,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.UpdateSniMatchRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'RemoveSniMatch': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveSniMatch,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.RemoveSniMatchRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetTargetStates': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTargetStates,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.GetTargetStatesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.GetTargetStatesResponse.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancerOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancerOperationsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.apploadbalancer.v1.LoadBalancerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LoadBalancerService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Get',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.GetLoadBalancerRequest.SerializeToString,
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2.LoadBalancer.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/List',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancersRequest.SerializeToString,
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Create',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.CreateLoadBalancerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Update',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.UpdateLoadBalancerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Delete',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.DeleteLoadBalancerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Start(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Start',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.StartLoadBalancerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Stop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/Stop',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.StopLoadBalancerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddListener(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/AddListener',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.AddListenerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveListener(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/RemoveListener',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.RemoveListenerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateListener(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/UpdateListener',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.UpdateListenerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddSniMatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/AddSniMatch',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.AddSniMatchRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSniMatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/UpdateSniMatch',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.UpdateSniMatchRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveSniMatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/RemoveSniMatch',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.RemoveSniMatchRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTargetStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/GetTargetStates',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.GetTargetStatesRequest.SerializeToString,
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.GetTargetStatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.apploadbalancer.v1.LoadBalancerService/ListOperations',
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancerOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__service__pb2.ListLoadBalancerOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
