# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/translate/v2/translation_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.ai.translate.v2 import translation_pb2 as yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ai/translate/v2/translation_service.proto',
  package='yandex.cloud.ai.translate.v2',
  syntax='proto3',
  serialized_options=b'\n yandex.cloud.api.ai.translate.v2ZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/translate/v2;translate',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6yandex/cloud/ai/translate/v2/translation_service.proto\x12\x1cyandex.cloud.ai.translate.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a.yandex/cloud/ai/translate/v2/translation.proto\"\x84\x03\n\x10TranslateRequest\x12%\n\x14source_language_code\x18\x01 \x01(\tB\x07\x8a\xc8\x31\x03<=3\x12)\n\x14target_language_code\x18\x02 \x01(\tB\x0b\xe8\xc7\x31\x01\x8a\xc8\x31\x03<=3\x12\x45\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\x35.yandex.cloud.ai.translate.v2.TranslateRequest.Format\x12\x15\n\x05texts\x18\x04 \x03(\tB\x06\x82\xc8\x31\x02>0\x12\x1b\n\tfolder_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x17\n\x05model\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12N\n\x0fglossary_config\x18\x07 \x01(\x0b\x32\x35.yandex.cloud.ai.translate.v2.TranslateGlossaryConfig\":\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x0e\n\nPLAIN_TEXT\x10\x01\x12\x08\n\x04HTML\x10\x02\"w\n\x17TranslateGlossaryConfig\x12\x43\n\rglossary_data\x18\x01 \x01(\x0b\x32*.yandex.cloud.ai.translate.v2.GlossaryDataH\x00\x42\x17\n\x0fglossary_source\x12\x04\xc0\xc1\x31\x01\"\\\n\x0cGlossaryData\x12L\n\x0eglossary_pairs\x18\x01 \x03(\x0b\x32*.yandex.cloud.ai.translate.v2.GlossaryPairB\x08\x82\xc8\x31\x04\x31-50\"H\n\x0cGlossaryPair\x12\x19\n\x0bsource_text\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\x0ftranslated_text\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"W\n\x11TranslateResponse\x12\x42\n\x0ctranslations\x18\x01 \x03(\x0b\x32,.yandex.cloud.ai.translate.v2.TranslatedText\"\x80\x01\n\x15\x44\x65tectLanguageRequest\x12\x1c\n\x04text\x18\x01 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1000\x12,\n\x13language_code_hints\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x04<=10\x8a\xc8\x31\x03<=3\x12\x1b\n\tfolder_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"/\n\x16\x44\x65tectLanguageResponse\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\"3\n\x14ListLanguagesRequest\x12\x1b\n\tfolder_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"R\n\x15ListLanguagesResponse\x12\x39\n\tlanguages\x18\x01 \x03(\x0b\x32&.yandex.cloud.ai.translate.v2.Language2\xe5\x03\n\x12TranslationService\x12\x90\x01\n\tTranslate\x12..yandex.cloud.ai.translate.v2.TranslateRequest\x1a/.yandex.cloud.ai.translate.v2.TranslateResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/translate/v2/translate:\x01*\x12\x9c\x01\n\x0e\x44\x65tectLanguage\x12\x33.yandex.cloud.ai.translate.v2.DetectLanguageRequest\x1a\x34.yandex.cloud.ai.translate.v2.DetectLanguageResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/translate/v2/detect:\x01*\x12\x9c\x01\n\rListLanguages\x12\x32.yandex.cloud.ai.translate.v2.ListLanguagesRequest\x1a\x33.yandex.cloud.ai.translate.v2.ListLanguagesResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/translate/v2/languages:\x01*Bn\n yandex.cloud.api.ai.translate.v2ZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/translate/v2;translateb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__pb2.DESCRIPTOR,])



_TRANSLATEREQUEST_FORMAT = _descriptor.EnumDescriptor(
  name='Format',
  full_name='yandex.cloud.ai.translate.v2.TranslateRequest.Format',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FORMAT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLAIN_TEXT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTML', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=528,
  serialized_end=586,
)
_sym_db.RegisterEnumDescriptor(_TRANSLATEREQUEST_FORMAT)


_TRANSLATEREQUEST = _descriptor.Descriptor(
  name='TranslateRequest',
  full_name='yandex.cloud.ai.translate.v2.TranslateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_language_code', full_name='yandex.cloud.ai.translate.v2.TranslateRequest.source_language_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\003<=3', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_language_code', full_name='yandex.cloud.ai.translate.v2.TranslateRequest.target_language_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\003<=3', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='yandex.cloud.ai.translate.v2.TranslateRequest.format', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='texts', full_name='yandex.cloud.ai.translate.v2.TranslateRequest.texts', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.ai.translate.v2.TranslateRequest.folder_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='yandex.cloud.ai.translate.v2.TranslateRequest.model', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='glossary_config', full_name='yandex.cloud.ai.translate.v2.TranslateRequest.glossary_config', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRANSLATEREQUEST_FORMAT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=198,
  serialized_end=586,
)


_TRANSLATEGLOSSARYCONFIG = _descriptor.Descriptor(
  name='TranslateGlossaryConfig',
  full_name='yandex.cloud.ai.translate.v2.TranslateGlossaryConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='glossary_data', full_name='yandex.cloud.ai.translate.v2.TranslateGlossaryConfig.glossary_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='glossary_source', full_name='yandex.cloud.ai.translate.v2.TranslateGlossaryConfig.glossary_source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=588,
  serialized_end=707,
)


_GLOSSARYDATA = _descriptor.Descriptor(
  name='GlossaryData',
  full_name='yandex.cloud.ai.translate.v2.GlossaryData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='glossary_pairs', full_name='yandex.cloud.ai.translate.v2.GlossaryData.glossary_pairs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\0041-50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=709,
  serialized_end=801,
)


_GLOSSARYPAIR = _descriptor.Descriptor(
  name='GlossaryPair',
  full_name='yandex.cloud.ai.translate.v2.GlossaryPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_text', full_name='yandex.cloud.ai.translate.v2.GlossaryPair.source_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='translated_text', full_name='yandex.cloud.ai.translate.v2.GlossaryPair.translated_text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=803,
  serialized_end=875,
)


_TRANSLATERESPONSE = _descriptor.Descriptor(
  name='TranslateResponse',
  full_name='yandex.cloud.ai.translate.v2.TranslateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='translations', full_name='yandex.cloud.ai.translate.v2.TranslateResponse.translations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=877,
  serialized_end=964,
)


_DETECTLANGUAGEREQUEST = _descriptor.Descriptor(
  name='DetectLanguageRequest',
  full_name='yandex.cloud.ai.translate.v2.DetectLanguageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='yandex.cloud.ai.translate.v2.DetectLanguageRequest.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language_code_hints', full_name='yandex.cloud.ai.translate.v2.DetectLanguageRequest.language_code_hints', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=10\212\3101\003<=3', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.ai.translate.v2.DetectLanguageRequest.folder_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=967,
  serialized_end=1095,
)


_DETECTLANGUAGERESPONSE = _descriptor.Descriptor(
  name='DetectLanguageResponse',
  full_name='yandex.cloud.ai.translate.v2.DetectLanguageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language_code', full_name='yandex.cloud.ai.translate.v2.DetectLanguageResponse.language_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1097,
  serialized_end=1144,
)


_LISTLANGUAGESREQUEST = _descriptor.Descriptor(
  name='ListLanguagesRequest',
  full_name='yandex.cloud.ai.translate.v2.ListLanguagesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.ai.translate.v2.ListLanguagesRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1146,
  serialized_end=1197,
)


_LISTLANGUAGESRESPONSE = _descriptor.Descriptor(
  name='ListLanguagesResponse',
  full_name='yandex.cloud.ai.translate.v2.ListLanguagesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='languages', full_name='yandex.cloud.ai.translate.v2.ListLanguagesResponse.languages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1199,
  serialized_end=1281,
)

_TRANSLATEREQUEST.fields_by_name['format'].enum_type = _TRANSLATEREQUEST_FORMAT
_TRANSLATEREQUEST.fields_by_name['glossary_config'].message_type = _TRANSLATEGLOSSARYCONFIG
_TRANSLATEREQUEST_FORMAT.containing_type = _TRANSLATEREQUEST
_TRANSLATEGLOSSARYCONFIG.fields_by_name['glossary_data'].message_type = _GLOSSARYDATA
_TRANSLATEGLOSSARYCONFIG.oneofs_by_name['glossary_source'].fields.append(
  _TRANSLATEGLOSSARYCONFIG.fields_by_name['glossary_data'])
_TRANSLATEGLOSSARYCONFIG.fields_by_name['glossary_data'].containing_oneof = _TRANSLATEGLOSSARYCONFIG.oneofs_by_name['glossary_source']
_GLOSSARYDATA.fields_by_name['glossary_pairs'].message_type = _GLOSSARYPAIR
_TRANSLATERESPONSE.fields_by_name['translations'].message_type = yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__pb2._TRANSLATEDTEXT
_LISTLANGUAGESRESPONSE.fields_by_name['languages'].message_type = yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__pb2._LANGUAGE
DESCRIPTOR.message_types_by_name['TranslateRequest'] = _TRANSLATEREQUEST
DESCRIPTOR.message_types_by_name['TranslateGlossaryConfig'] = _TRANSLATEGLOSSARYCONFIG
DESCRIPTOR.message_types_by_name['GlossaryData'] = _GLOSSARYDATA
DESCRIPTOR.message_types_by_name['GlossaryPair'] = _GLOSSARYPAIR
DESCRIPTOR.message_types_by_name['TranslateResponse'] = _TRANSLATERESPONSE
DESCRIPTOR.message_types_by_name['DetectLanguageRequest'] = _DETECTLANGUAGEREQUEST
DESCRIPTOR.message_types_by_name['DetectLanguageResponse'] = _DETECTLANGUAGERESPONSE
DESCRIPTOR.message_types_by_name['ListLanguagesRequest'] = _LISTLANGUAGESREQUEST
DESCRIPTOR.message_types_by_name['ListLanguagesResponse'] = _LISTLANGUAGESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TranslateRequest = _reflection.GeneratedProtocolMessageType('TranslateRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATEREQUEST,
  '__module__' : 'yandex.cloud.ai.translate.v2.translation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.translate.v2.TranslateRequest)
  })
_sym_db.RegisterMessage(TranslateRequest)

TranslateGlossaryConfig = _reflection.GeneratedProtocolMessageType('TranslateGlossaryConfig', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATEGLOSSARYCONFIG,
  '__module__' : 'yandex.cloud.ai.translate.v2.translation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.translate.v2.TranslateGlossaryConfig)
  })
_sym_db.RegisterMessage(TranslateGlossaryConfig)

GlossaryData = _reflection.GeneratedProtocolMessageType('GlossaryData', (_message.Message,), {
  'DESCRIPTOR' : _GLOSSARYDATA,
  '__module__' : 'yandex.cloud.ai.translate.v2.translation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.translate.v2.GlossaryData)
  })
_sym_db.RegisterMessage(GlossaryData)

GlossaryPair = _reflection.GeneratedProtocolMessageType('GlossaryPair', (_message.Message,), {
  'DESCRIPTOR' : _GLOSSARYPAIR,
  '__module__' : 'yandex.cloud.ai.translate.v2.translation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.translate.v2.GlossaryPair)
  })
_sym_db.RegisterMessage(GlossaryPair)

TranslateResponse = _reflection.GeneratedProtocolMessageType('TranslateResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRANSLATERESPONSE,
  '__module__' : 'yandex.cloud.ai.translate.v2.translation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.translate.v2.TranslateResponse)
  })
_sym_db.RegisterMessage(TranslateResponse)

DetectLanguageRequest = _reflection.GeneratedProtocolMessageType('DetectLanguageRequest', (_message.Message,), {
  'DESCRIPTOR' : _DETECTLANGUAGEREQUEST,
  '__module__' : 'yandex.cloud.ai.translate.v2.translation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.translate.v2.DetectLanguageRequest)
  })
_sym_db.RegisterMessage(DetectLanguageRequest)

DetectLanguageResponse = _reflection.GeneratedProtocolMessageType('DetectLanguageResponse', (_message.Message,), {
  'DESCRIPTOR' : _DETECTLANGUAGERESPONSE,
  '__module__' : 'yandex.cloud.ai.translate.v2.translation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.translate.v2.DetectLanguageResponse)
  })
_sym_db.RegisterMessage(DetectLanguageResponse)

ListLanguagesRequest = _reflection.GeneratedProtocolMessageType('ListLanguagesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLANGUAGESREQUEST,
  '__module__' : 'yandex.cloud.ai.translate.v2.translation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.translate.v2.ListLanguagesRequest)
  })
_sym_db.RegisterMessage(ListLanguagesRequest)

ListLanguagesResponse = _reflection.GeneratedProtocolMessageType('ListLanguagesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLANGUAGESRESPONSE,
  '__module__' : 'yandex.cloud.ai.translate.v2.translation_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.translate.v2.ListLanguagesResponse)
  })
_sym_db.RegisterMessage(ListLanguagesResponse)


DESCRIPTOR._options = None
_TRANSLATEREQUEST.fields_by_name['source_language_code']._options = None
_TRANSLATEREQUEST.fields_by_name['target_language_code']._options = None
_TRANSLATEREQUEST.fields_by_name['texts']._options = None
_TRANSLATEREQUEST.fields_by_name['folder_id']._options = None
_TRANSLATEREQUEST.fields_by_name['model']._options = None
_TRANSLATEGLOSSARYCONFIG.oneofs_by_name['glossary_source']._options = None
_GLOSSARYDATA.fields_by_name['glossary_pairs']._options = None
_GLOSSARYPAIR.fields_by_name['source_text']._options = None
_GLOSSARYPAIR.fields_by_name['translated_text']._options = None
_DETECTLANGUAGEREQUEST.fields_by_name['text']._options = None
_DETECTLANGUAGEREQUEST.fields_by_name['language_code_hints']._options = None
_DETECTLANGUAGEREQUEST.fields_by_name['folder_id']._options = None
_LISTLANGUAGESREQUEST.fields_by_name['folder_id']._options = None

_TRANSLATIONSERVICE = _descriptor.ServiceDescriptor(
  name='TranslationService',
  full_name='yandex.cloud.ai.translate.v2.TranslationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1284,
  serialized_end=1769,
  methods=[
  _descriptor.MethodDescriptor(
    name='Translate',
    full_name='yandex.cloud.ai.translate.v2.TranslationService.Translate',
    index=0,
    containing_service=None,
    input_type=_TRANSLATEREQUEST,
    output_type=_TRANSLATERESPONSE,
    serialized_options=b'\202\323\344\223\002\034\"\027/translate/v2/translate:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DetectLanguage',
    full_name='yandex.cloud.ai.translate.v2.TranslationService.DetectLanguage',
    index=1,
    containing_service=None,
    input_type=_DETECTLANGUAGEREQUEST,
    output_type=_DETECTLANGUAGERESPONSE,
    serialized_options=b'\202\323\344\223\002\031\"\024/translate/v2/detect:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLanguages',
    full_name='yandex.cloud.ai.translate.v2.TranslationService.ListLanguages',
    index=2,
    containing_service=None,
    input_type=_LISTLANGUAGESREQUEST,
    output_type=_LISTLANGUAGESRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\"\027/translate/v2/languages:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRANSLATIONSERVICE)

DESCRIPTOR.services_by_name['TranslationService'] = _TRANSLATIONSERVICE

# @@protoc_insertion_point(module_scope)
